Enum PresentationHint
#[non_exhaustive]#[repr(u32)]pub enum PresentationHint {
Vsync = 0,
Async = 1,
}Available on crate feature
wayland and Linux only.Expand description
presentation hint values
This enum provides information for if submitted frames from the client may be presented with tearing.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Vsync = 0
tearing-free presentation
The content of this surface is meant to be synchronized to the vertical blanking period. This should not result in visible tearing and may result in a delay before a surface commit is presented.
Async = 1
asynchronous presentation
The content of this surface is meant to be presented with minimal latency and tearing is acceptable.