Struct WpTearingControlV1
pub struct WpTearingControlV1 { /* private fields */ }wayland and Linux only.Expand description
per-surface tearing control interface
An additional interface to a wl_surface object, which allows the client to hint to the compositor if the content on the surface is suitable for presentation with tearing. The default presentation hint is vsync. See presentation_hint for more details.
If the associated wl_surface is destroyed, this object becomes inert and should be destroyed.
This interface has no events.
Implementations
impl WpTearingControlV1
impl WpTearingControlV1
pub fn set_presentation_hint(&self, hint: PresentationHint)
pub fn set_presentation_hint(&self, hint: PresentationHint)
set presentation hint
Set the presentation hint for the associated wl_surface. This state is double-buffered, see wl_surface.commit.
The compositor is free to dynamically respect or ignore this hint based on various conditions like hardware capabilities, surface state and user preferences.
pub fn destroy(&self)
pub fn destroy(&self)
destroy tearing control object
Destroy this surface tearing object and revert the presentation hint to vsync. The change will be applied on the next wl_surface.commit.